@@ -24,7 +24,7 @@ class AzureProvider(AbstractProvider):
         """
             Tries to identify Azure using all the implemented options
         """
-        self.logger.info('Try to identify DO')
+        self.logger.info('Try to identify Azure')
         return self.check_vendor_file() or await self.check_metadata_server()
 
     async def check_metadata_server(self):
@@ -44,8 +44,8 @@ class AzureProvider(AbstractProvider):
             Tries to identify Azure provider by reading the /sys/class/dmi/id/sys_vendor
         """
         self.logger.debug('Checking Azure vendor file')
-        do_path = Path(self.vendor_file)
-        if do_path.is_file():
-            if 'Microsoft Corporation' in open(self.vendor_file).read():
+        ms_path = Path(self.vendor_file)
+        if ms_path.is_file():
+            if 'Microsoft Corporation' in ms_path.read_text():
                 return True
         return False
